// Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
// or more contributor license agreements. Licensed under the Elastic License;
// you may not use this file except in compliance with the Elastic License.

package cef

// fullNameMapping is a mapping of CEF key names to full field names.
// This mapping was generated from tables contained in "Micro Focus Security
// ArcSight Common Event Format Version 25" dated September 28, 2017.
var fullNameMapping = map[string]string{
	"agt":                                 "agentAddress",
	"agentDnsDomain":                      "agentDnsDomain",
	"ahost":                               "agentHostName",
	"aid":                                 "agentId",
	"amac":                                "agentMacAddress",
	"agentNtDomain":                       "agentNtDomain",
	"art":                                 "agentReceiptTime",
	"atz":                                 "agentTimeZone",
	"agentTranslatedAddress":              "agentTranslatedAddress",
	"agentTranslatedZoneExternalID":       "agentTranslatedZoneExternalID",
	"agentTranslatedZoneURI":              "agentTranslatedZoneURI",
	"at":                                  "agentType",
	"av":                                  "agentVersion",
	"agentZoneExternalID":                 "agentZoneExternalID",
	"agentZoneURI":                        "agentZoneURI",
	"app":                                 "applicationProtocol",
	"cnt":                                 "baseEventCount",
	"in":                                  "bytesIn",
	"out":                                 "bytesOut",
	"customerExternalID":                  "customerExternalID",
	"customerURI":                         "customerURI",
	"dst":                                 "destinationAddress",
	"destinationDnsDomain":                "destinationDnsDomain",
	"dlat":                                "destinationGeoLatitude",
	"dlong":                               "destinationGeoLongitude",
	"dhost":                               "destinationHostName",
	"dmac":                                "destinationMacAddress",
	"dntdom":                              "destinationNtDomain",
	"dpt":                                 "destinationPort",
	"dpid":                                "destinationProcessId",
	"dproc":                               "destinationProcessName",
	"destinationServiceName":              "destinationServiceName",
	"destinationTranslatedAddress":        "destinationTranslatedAddress",
	"destinationTranslatedPort":           "destinationTranslatedPort",
	"destinationTranslatedZoneExternalID": "destinationTranslatedZoneExternalID",
	"destinationTranslatedZoneURI":        "destinationTranslatedZoneURI",
	"duid":                                "destinationUserId",
	"duser":                               "destinationUserName",
	"dpriv":                               "destinationUserPrivileges",
	"destinationZoneExternalID":           "destinationZoneExternalID",
	"destinationZoneURI":                  "destinationZoneURI",
	"act":                                 "deviceAction",
	"dvc":                                 "deviceAddress",
	"cfp1Label":                           "deviceCustomFloatingPoint1Label",
	"cfp3Label":                           "deviceCustomFloatingPoint3Label",
	"cfp4Label":                           "deviceCustomFloatingPoint4Label",
	"deviceCustomDate1":                   "deviceCustomDate1",
	"deviceCustomDate1Label":              "deviceCustomDate1Label",
	"deviceCustomDate2":                   "deviceCustomDate2",
	"deviceCustomDate2Label":              "deviceCustomDate2Label",
	"cfp1":                                "deviceCustomFloatingPoint1",
	"cfp2":                                "deviceCustomFloatingPoint2",
	"cfp2Label":                           "deviceCustomFloatingPoint2Label",
	"cfp3":                                "deviceCustomFloatingPoint3",
	"cfp4":                                "deviceCustomFloatingPoint4",
	"c6a1Label":                           "deviceCustomIPv6Address1Label",
	"c6a4":                                "deviceCustomIPv6Address4",
	"C6a4Label":                           "deviceCustomIPv6Address4Label",
	"c6a1":                                "deviceCustomIPv6Address1",
	"c6a3":                                "deviceCustomIPv6Address3",
	"c6a3Label":                           "deviceCustomIPv6Address3Label",
	"cn1":                                 "deviceCustomNumber1",
	"cn1Label":                            "deviceCustomNumber1Label",
	"cn2":                                 "DeviceCustomNumber2",
	"cn2Label":                            "deviceCustomNumber2Label",
	"cn3":                                 "deviceCustomNumber3",
	"cn3Label":                            "deviceCustomNumber3Label",
	"cs1":                                 "deviceCustomString1",
	"cs1Label":                            "deviceCustomString1Label",
	"cs2":                                 "deviceCustomString2",
	"cs2Label":                            "deviceCustomString2Label",
	"cs3":                                 "deviceCustomString3",
	"cs3Label":                            "deviceCustomString3Label",
	"cs4":                                 "deviceCustomString4",
	"cs4Label":                            "deviceCustomString4Label",
	"cs5":                                 "deviceCustomString5",
	"cs5Label":                            "deviceCustomString5Label",
	"cs6":                                 "deviceCustomString6",
	"cs6Label":                            "deviceCustomString6Label",
	"deviceDirection":                     "deviceDirection",
	"deviceDnsDomain":                     "deviceDnsDomain",
	"cat":                                 "deviceEventCategory",
	"deviceExternalId":                    "deviceExternalId",
	"deviceFacility":                      "deviceFacility",
	"dvchost":                             "deviceHostName",
	"deviceInboundInterface":              "deviceInboundInterface",
	"dvcmac":                              "deviceMacAddress",
	"deviceNtDomain":                      "deviceNtDomain",
	"DeviceOutboundInterface":             "deviceOutboundInterface",
	"DevicePayloadId":                     "devicePayloadId",
	"dvcpid":                              "deviceProcessId",
	"deviceProcessName":                   "deviceProcessName",
	"rt":                                  "deviceReceiptTime",
	"dtz":                                 "deviceTimeZone",
	"deviceTranslatedAddress":             "deviceTranslatedAddress",
	"deviceTranslatedZoneExternalID":      "deviceTranslatedZoneExternalID",
	"deviceTranslatedZoneURI":             "deviceTranslatedZoneURI",
	"deviceZoneExternalID":                "deviceZoneExternalID",
	"deviceZoneURI":                       "deviceZoneURI",
	"end":                                 "endTime",
	"eventId":                             "eventId",
	"outcome":                             "eventOutcome",
	"externalId":                          "externalId",
	"fileCreateTime":                      "fileCreateTime",
	"fileHash":                            "fileHash",
	"fileId":                              "fileId",
	"fileModificationTime":                "fileModificationTime",
	"fname":                               "filename",
	"filePath":                            "filePath",
	"filePermission":                      "filePermission",
	"fsize":                               "fileSize",
	"fileType":                            "fileType",
	"flexDate1":                           "flexDate1",
	"flexDate1Label":                      "flexDate1Label",
	"flexString1":                         "flexString1",
	"flexString2":                         "flexString2",
	"flexString1Label":                    "flexString2Label",
	"flexString2Label":                    "flexString2Label",
	"msg":                                 "message",
	"oldFileCreateTime":                   "oldFileCreateTime",
	"oldFileHash":                         "oldFileHash",
	"oldFileId":                           "oldFileId",
	"oldFileModificationTime":             "oldFileModificationTime",
	"oldFileName":                         "oldFileName",
	"oldFilePath":                         "oldFilePath",
	"oldFilePermission":                   "oldFilePermission",
	"oldFileSize":                         "oldFileSize",
	"oldFileType":                         "oldFileType",
	"rawEvent":                            "rawEvent",
	"reason":                              "Reason",
	"requestClientApplication":            "requestClientApplication",
	"requestContext":                      "requestContext",
	"requestCookies":                      "requestCookies",
	"requestMethod":                       "requestMethod",
	"request":                             "requestUrl",
	"src":                                 "sourceAddress",
	"sourceDnsDomain":                     "sourceDnsDomain",
	"slat":                                "sourceGeoLatitude",
	"slong":                               "sourceGeoLongitude",
	"shost":                               "sourceHostName",
	"smac":                                "sourceMacAddress",
	"sntdom":                              "sourceNtDomain",
	"spt":                                 "sourcePort",
	"spid":                                "sourceProcessId",
	"sproc":                               "sourceProcessName",
	"sourceServiceName":                   "sourceServiceName",
	"sourceTranslated":                    "Address",
	"sourceTranslatedPort":                "sourceTranslatedPort",
	"sourceTranslatedZoneExternalID":      "sourceTranslatedZoneExternalID",
	"sourceTranslatedZoneURI":             "sourceTranslatedZoneURI",
	"suid":                                "sourceUserId",
	"suser":                               "sourceUserName",
	"spriv":                               "sourceUserPrivileges",
	"sourceZoneExternalID":                "sourceZoneExternalID",
	"sourceZoneURI":                       "sourceZoneURI",
	"start":                               "startTime",
	"proto":                               "transportProtocol",
	"type":                                "type",

	// This is an ArcSight categorization field that is commonly used, but its
	// short name is not contained in the documentation used for the above list.
	"catdt": "categoryDeviceType",
}
